@@ -79,10 +79,11 @@ from .phonemetadata import REGION_CODE_FOR_NON_GEO_ENTITY, NumberFormat, PhoneNu
 # Functionality
 from .asyoutypeformatter import AsYouTypeFormatter
 from .phonenumberutil import (COUNTRY_CODE_TO_REGION_CODE, SUPPORTED_REGIONS,
-                              SUPPORTED_SHORT_REGIONS, UNKNOWN_REGION, COUNTRY_CODES_FOR_NON_GEO_REGIONS,
+                              UNKNOWN_REGION, COUNTRY_CODES_FOR_NON_GEO_REGIONS,
                               NON_DIGITS_PATTERN,
                               MatchType, NumberParseException, PhoneNumberFormat,
                               PhoneNumberType, ValidationResult,
+                              can_be_internationally_dialled,
                               convert_alpha_characters_in_number,
                               country_code_for_region,
                               country_code_for_valid_region,
@@ -105,6 +106,8 @@ from .phonenumberutil import (COUNTRY_CODE_TO_REGION_CODE, SUPPORTED_REGIONS,
                               is_number_geographical,
                               is_number_type_geographical,
                               is_possible_number,
+                              is_possible_number_for_type,
+                              is_possible_number_for_type_with_reason,
                               is_possible_number_string,
                               is_possible_number_with_reason,
                               is_valid_number,
@@ -121,9 +124,13 @@ from .phonenumberutil import (COUNTRY_CODE_TO_REGION_CODE, SUPPORTED_REGIONS,
                               region_code_for_country_code,
                               region_codes_for_country_code,
                               region_code_for_number,
+                              supported_calling_codes,
+                              supported_types_for_region,
+                              supported_types_for_non_geo_entity,
                               truncate_too_long_number,
                               is_mobile_number_portable_region,)
-from .shortnumberinfo import (ShortNumberCost,
+from .shortnumberinfo import (SUPPORTED_SHORT_REGIONS,
+                              ShortNumberCost,
                               is_possible_short_number_for_region,
                               is_possible_short_number,
                               is_valid_short_number_for_region,
@@ -133,23 +140,25 @@ from .shortnumberinfo import (ShortNumberCost,
                               connects_to_emergency_number,
                               is_emergency_number,
                               is_carrier_specific,
-                              is_carrier_specific_for_region)
+                              is_carrier_specific_for_region,
+                              is_sms_service_for_region)
 from .phonenumbermatcher import PhoneNumberMatch, PhoneNumberMatcher, Leniency
 
 
 # Version number is taken from the upstream libphonenumber version
 # together with an indication of the version of the Python-specific code.
-__version__ = "8.3.2"
+__version__ = "8.8.2"
 
 __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'REGION_CODE_FOR_NON_GEO_ENTITY', 'NumberFormat', 'PhoneNumberDesc', 'PhoneMetadata',
            'AsYouTypeFormatter',
            # items from phonenumberutil.py
            'COUNTRY_CODE_TO_REGION_CODE', 'SUPPORTED_REGIONS',
-           'SUPPORTED_SHORT_REGIONS', 'UNKNOWN_REGION', 'COUNTRY_CODES_FOR_NON_GEO_REGIONS',
+           'UNKNOWN_REGION', 'COUNTRY_CODES_FOR_NON_GEO_REGIONS',
            'NON_DIGITS_PATTERN',
            'MatchType', 'NumberParseException', 'PhoneNumberFormat',
            'PhoneNumberType', 'ValidationResult',
+           'can_be_internationally_dialled',
            'convert_alpha_characters_in_number',
            'country_code_for_region',
            'country_code_for_valid_region',
@@ -172,6 +181,8 @@ __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'is_number_type_geographical',
            'is_number_match',
            'is_possible_number',
+           'is_possible_number_for_type',
+           'is_possible_number_for_type_with_reason',
            'is_possible_number_string',
            'is_possible_number_with_reason',
            'is_valid_number',
@@ -187,10 +198,14 @@ __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'region_code_for_country_code',
            'region_codes_for_country_code',
            'region_code_for_number',
+           'supported_calling_codes',
+           'supported_types_for_region',
+           'supported_types_for_non_geo_entity',
            'truncate_too_long_number',
            'is_mobile_number_portable_region',
            # end of items from phonenumberutil.py
            # items from shortnumberinfo.py
+           'SUPPORTED_SHORT_REGIONS',
            'ShortNumberCost',
            'is_possible_short_number_for_region',
            'is_possible_short_number',
@@ -202,6 +217,7 @@ __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'is_emergency_number',
            'is_carrier_specific',
            'is_carrier_specific_for_region',
+           'is_sms_service_for_region',
            # end of items from shortnumberinfo.py
            'PhoneNumberMatch', 'PhoneNumberMatcher', 'Leniency',
            ]
